@@ -4,7 +4,7 @@
 # Based on yamas v1.0 by comaX for pcsci3ence.info
 
 #Version information
-version=1.0
+version=1.0.1
 
 # device variables
 pathLog=/home/user/yamas
@@ -19,112 +19,7 @@ if [ "$(id -u)" != "0" ]; then
    exit
 fi
 
-#Check if the required dependencies exist.
-dep() {
-   echo; echo -en "Checking for the needed dependencies:\n"
-   echo -en "\t wget\t\t"
-   if dpkg -l | grep wget 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   echo -en "\t busybox-power\t"
-   if dpkg -l | grep -w busybox-power 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   echo -en "\t Dsniff(arpspoof)\t"
-   if dpkg -l | grep -w dsniff 1>/dev/null; then 
-     echo -e "\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   echo -en "\t xterm\t\t"
-   if dpkg -l | grep -w " xterm" 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   echo -en "\t iptables\t"
-   if dpkg -l | grep iptables 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-     
-   echo -en "\t nmap\t\t"
-   if dpkg -l | grep nmap 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-
-   echo -en "\t grep\t\t"
-   if dpkg -l | grep libpcre3 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   echo -en "\t pcap\t\t"
-   if dpkg -l | grep libpcap0.8 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 > ./test.txt
-   fi
-          
-   echo -en "\t sslstrip\t"
-   if dpkg -l | grep sslstrip 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-     
-    echo -en "\t python-twisted-web"
-   if dpkg -l | grep python-twisted-web 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-
-   echo -en "\t python-openssl"
-   if dpkg -l | grep python-openssl 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-   
-   if [ ! -e "./test.txt" ]; then
-      echo "All right ! Let's keep rolling..."
-      echo 1 > $pathLog/.ok
-   else
-      rm ./test.txt
-      if [ -e "$pathLog/.ok" ]; then rm $pathLog/.ok; fi
-      echo "You are missing dependencies, this script will fail : exiting ! "
-      sleep 3
-
-      exit 0
-   fi
-}
-
-if [ ! -e "$pathLog/.ok" ]; then dep; fi
-#Check if yamas folder exists, if not create it
+#Check if the logs storage folder exists, if not create it
 if [ ! -d "$pathLog" ]; then
    mkdir $pathLog
 fi
@@ -133,10 +28,6 @@ args=
 while [ "$#" -ge 1 ] #check parameters
 do
   case $1 in
-   -d | --depend) # force check for dependencies
-      clear
-      dep # calling the function.
-      ;;
       
    -e | --ettercap) etter=1 ;;
       
